/*
	$Id $

	Copyright (C) 2013 Nicklas Nordborg
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions;

import java.util.Iterator;

import net.sf.basedb.util.extensions.Action;
import net.sf.basedb.util.extensions.Renderer;

/**
	Supplementary interface for actions that need to be able to support
	dynamic attributes that are not pre-defined by the actual {@link Action}.
	Typcially, dynamic attributes are rendered (in HTML pages) as
	extra attributes in the main tag. For example:
	
	<pre class="code">
&lt;div ... data-extra-attribute="extra-value"&gt;...
</pre>
	
	For this to work, a {@link Renderer} implementation need to check if
	this interface is implemented by the action and then use this information
	for furthere processing. A few helper classes exists:
	
	<ul>
	<li>{@link DynamicActionAttributeSupport}: Abstract base class that can
		be extended by actions to add support for this interface.
	</ul>
	
	@author nicklas
	@since 3.3
*/
public interface DynamicActionAttributes 
{
	/**
		Get an iterator that return all dynamic attributes. If no
		dynamic attributes have been defined, the method may return null
		or an iterator that doesn't return any elements.
		@return An iterator or null
	*/
	public Iterator<DynamicActionAttribute> getDynamicActionAttributes();
	
}
