/**
	$Id: InstalledFileProcessor.java 5616 2011-04-27 09:27:56Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions;

import net.sf.basedb.util.extensions.manager.ExtensionsFile;
import net.sf.basedb.util.extensions.manager.ExtensionsManager;
import net.sf.basedb.util.extensions.manager.ProcessResults;
import net.sf.basedb.util.extensions.manager.ExtensionsFile.WriteableExtensionsFile;
import net.sf.basedb.util.extensions.manager.ProcessResults.FileResults;
import net.sf.basedb.util.extensions.manager.processor.MarkAsProcessedProcessor;

/**
	File processor implementation that sets a final result status for each
	processed file (eg. "Installed", "Updated", "Deleted", etc). It will
	also mark all files as processed and installed.
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-27 11:27:56 +0200 (ons, 27 apr. 2011) $
*/
public class InstalledFileProcessor
	extends MarkAsProcessedProcessor
{

	private final ProcessResults results;
	public InstalledFileProcessor(ProcessResults results)
	{
		super();
		this.results = results;
	}
	
	/*
		From the RegisterExtensionsProcessor class
		------------------------------------------
	*/
	@Override
	public void processFile(ExtensionsManager manager, WriteableExtensionsFile wFile)
	{
		ExtensionsFile xtFile = wFile.getExtensionsFile();
		FileResults fileResults = results.getResults(xtFile);
		if (!xtFile.isValid())
		{
			results.setStatus(xtFile, "Invalid");
		}
		else if (xtFile.hasError())
		{
			results.setStatus(xtFile, "Error");
		}
		else if (xtFile.isNew())
		{
			results.setStatus(xtFile, "Installed");
		}
		else if (xtFile.wasModified() || fileResults != null)
		{
			results.setStatus(xtFile, "Updated");
		}
		else
		{
			results.setStatus(xtFile, "Already installed");
		}
		wFile.setInstalled();
		super.processFile(manager, wFile);
	}
	// ------------------------------------------


}
