package net.sf.basedb.clients.web.extensions.list;

import java.util.LinkedHashSet;
import java.util.Set;

import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.Metadata;
import net.sf.basedb.core.Metadata.PropertyPath;
import net.sf.basedb.util.filter.Filter;

/**
	Parent item column that get values from parent items by specifying
	a "property path". See {@link Metadata}.

	@author nicklas
	@since 3.16
*/
public class ParentItemPropertyColumn 
	extends ParentItemColumn
{

	private final PropertyPath<? super Annotatable, ?> property;
	
	ParentItemPropertyColumn(int index, String id, Filter<Annotatable> filter, ParentItemHelper helper, PropertyPath<? super Annotatable, ?> property)
	{
		super(index, id, filter, helper);
		this.property = property;
	}
	
	@Override
	public Object getValue(ParentItemHelper helper, Annotatable item) 
	{
		Set<Annotatable> parents = getParentItems(item);
		if (parents.size() == 0) return null;

		Set<Object> values = new LinkedHashSet<>();
		for (Annotatable p : parents)
		{
			values.add(property == null ? p : property.getValue(helper.dc, p));
		}
		
		return values.size() == 0 ? null : values;
	}

}
