/**
	$Id: PrefixSuffixRenderer.java 4871 2009-04-01 12:58:27Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.renderer;

import java.io.IOException;

import javax.servlet.jsp.JspWriter;

import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.util.extensions.Action;
import net.sf.basedb.util.extensions.Renderer;
import net.sf.basedb.util.extensions.WrappingRenderer;

/**
	A wrapping renderer for HTML output that can wrap the
	HTML generated by a parent renderer with a prefix
	and/or suffix.
	
	@author Nicklas
	@version 2.12
	@base.modified $Date: 2009-04-01 14:58:27 +0200 (ons, 01 apr. 2009) $
*/
public class PrefixSuffixRenderer<A extends Action>
	implements WrappingRenderer<A>
{

	private JspContext context;
	private Renderer<? super A> parent;
	private String prefix;
	private String suffix;
	
	/**
		Create a prefix/suffix renderer that has no initial parent.
		@param context The jsp context
		@param prefix Optional prefix string
		@param suffix Optional suffix string
	 */
	public PrefixSuffixRenderer(JspContext context, String prefix, String suffix)
	{
		this.context = context;
		this.prefix = prefix;
		this.suffix = suffix;
	}

	/**
		Create a prefix/suffix renderer with an initial parent.
		@param context The jsp context
		@param parent The initial parent renderer
		@param prefix Optional prefix string
		@param suffix Optional suffix string
	*/
	public PrefixSuffixRenderer(JspContext context, Renderer<? super A> parent, 
		String prefix, String suffix)
	{
		this(context, prefix, suffix);
		this.parent = parent;
	}
	
	/*
		From the Renderer interface
		-------------------------------
	*/
	@Override
	public void render(A action)
	{
		JspWriter writer = context.getOut();
		try
		{
			if (prefix != null) writer.print(prefix);
			if (parent != null) parent.render(action);
			if (suffix != null) writer.print(suffix);
		}
		catch (IOException ex)
		{
			throw new RuntimeException(ex);
		}
	}
	// ----------------------------------------

	/*
		From the WrappingRenderer interface
		----------------------------------------
	*/
	@Override
	public Renderer<? super A> getParent()
	{
		return parent;
	}
	@Override
	public void setParent(Renderer<? super A> parent)
	{
		this.parent = parent;
	}
	// ----------------------------------------

}
