/**
	$Id: FixedButtonFactory.java 6875 2015-04-20 09:08:18Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.toolbar;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.util.Values;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.extensions.xml.PathSetter;
import net.sf.basedb.util.extensions.xml.VariableSetter;

/**
	A simple implementation of a toolbar button action factory that 
	creates the same fixed button for all users 
	not using any context information.
	<p>
	The button is by default both visible and enabled. Use the setter 
	method to change the properties. Changes to the properties are immediately
	visible in the menu items returned from the {@link #getActions(InvokationContext)}
	method.
	<p>
	If the extension point supports scripts and stylesheets, use the
	{@link #setScript(String)} and {@link #setStylesheet(String)} methods.
	Each call to these methods will add the argument to a set. Use
	the {@link #getScripts()} and {@link #getStylesheets()} methods to gain
	access to the sets, for example, to remove added items.
	
	@author nicklas
	@version 2.7
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
*/
public class FixedButtonFactory 
	extends AbstractJspActionFactory<ButtonAction>
	implements ButtonAction 
	
{

	private ButtonAction[] actions;
	
	private String id;
	private String clazz;
	private String icon;
	private String style;
	private String title;
	private String tooltip;
	private boolean enabled;
	private boolean visible;
	private int tabIndex;
	
	/**
		Create a new factory instance.
	*/
	public FixedButtonFactory()
	{
		actions = new ButtonAction[] { this };
		enabled = true;
		visible = true;
	}
	
	/*
		From the ActionFactory interface
		--------------------------------
	*/
	@Override
	public ButtonAction[] getActions(InvokationContext<? super ButtonAction> context) 
	{
		return actions;
	}
	// ------------------------------------

	/*
		From the ButtonAction interface
		--------------------------------
	*/
	@Override
	public String getClazz() 
	{
		return clazz;
	}

	@Override
	public String getId() 
	{
		return id;
	}

	@Override
	public String getIcon() 
	{
		return icon;
	}

	@Override
	public String getStyle() 
	{
		return style;
	}

	@Override
	public String getTitle() 
	{
		return title;
	}

	@Override
	public String getTooltip() 
	{
		return tooltip;
	}

	@Override
	public boolean isEnabled() 
	{
		return enabled;
	}

	@Override
	public boolean isVisible() 
	{
		return visible;
	}
	
	@Override
	public int getTabIndex()
	{
		return tabIndex;
	}
	// ------------------------------------

	public void setClazz(String clazz) 
	{
		this.clazz = clazz;
	}

	@VariableSetter
	@PathSetter
	public void setIcon(String icon) 
	{
		this.icon = icon;
	}

	public void setId(String id) 
	{
		this.id = id;
	}

	public void setStyle(String style) 
	{
		this.style = style;
	}

	public void setTitle(String title) 
	{
		this.title = title;
	}

	public void setTooltip(String tooltip) 
	{
		this.tooltip = tooltip;
	}

	public void setEnabled(boolean enabled) 
	{
		this.enabled = enabled;
	}

	public void setEnabled(String enabled) 
	{
		this.enabled = Values.getBoolean(enabled);
	}

	public void setVisible(boolean visible) 
	{
		this.visible = visible;
	}

	public void setVisible(String visible) 
	{
		this.visible = Values.getBoolean(visible);
	}
	
	public void setTabIndex(int tabIndex)
	{
		this.tabIndex = tabIndex;
	}

}
