/*
	$Id$

	Copyright (C) 2018 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.formatter;

import net.sf.basedb.clients.web.Base;
import net.sf.basedb.core.Nameable;
import net.sf.basedb.util.formatter.Formatter;

/**
	Formatter implementation that generates a HTML output linking
	a nameable item. EDIT links are created by default.
	
	@author nicklas
	@since 3.12
	@see Base#getLinkedName(String, Nameable, boolean, boolean)
*/
public class LinkedItemFormatter 
	implements Formatter<Nameable>
{
	
	private final boolean enableEditLink;
	
	public LinkedItemFormatter() 
	{
		this(true);
	}
	
	public LinkedItemFormatter(boolean enableEditLink)
	{
		this.enableEditLink = enableEditLink;
	}

	@Override
	public String format(Nameable item) 
	{
		return Base.getLinkedName(null, item, false, enableEditLink);
	}

	@Override
	public Nameable parseString(String value) 
	{
		throw new UnsupportedOperationException("parseString: " + value);
	}

}
