/**
	$Id: ExportTemplate.java 7645 2019-03-12 09:56:19Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.plugins;

import java.io.Closeable;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import net.sf.basedb.core.ProgressReporter;

/**
 	A helper interface for the {@link SimpleExport} class to make it
	easier to output exported data in different formats.
	
	@author nicklas
	@version 2.2
	@base.modified $Date: 2019-03-12 10:56:19 +0100 (tis, 12 mars 2019) $
*/
public interface ExportTemplate
	extends Closeable
{
	/**
		Get the MIME type to assign to files generated by this template.
	 	@return a String 
	*/
	public String getMimeType();
	
	/**
		Get the default file extension to give to files generated by this template.
		@return The file extension (without .)
		@since 3.0
	*/
	public String getDefaultFileExtension();
	
	/**
		Start writing the document.
		@throws IOException If there is an error
	*/
	public void beginDocument()
		throws IOException;
	
	/**
		Write headers.
		@throws IOException If there is an error
	*/
	public void writeHeaders()
		throws IOException;
	
	/**
		Start writing a new item.
	 	@param id Id of the new item. 
		@throws IOException If there is an error
	*/
	public void beginItem(int id)
		throws IOException;
	
	/**
		Write annotation values.
	 	@param ep Exported property the annotations belongs to 
	 	@param values Annotation values to be written.
	 	@param unit The unit of the annotation values, or null
	 		to not display write a unit
		@throws IOException If there is an error
	*/
	public void writeAnnotations(ExportedProperty ep, List<?> values, String unit)
		throws IOException;
	
	/**
		Write the specified property values.
	 	@param ep The exported property the <code>data</code> belongs to.
	 	@param data Data to be written.
		@throws IOException If there is an error
	*/
	public void writeProperty(ExportedProperty ep, Object data)
		throws IOException;
	
	/**
	 	Write the values in a collection
	 	@param ep Exported property the values belong to
	 	@param values The values to be written
	 	@since 2.12
	 */
	public void writeCollection(ExportedProperty ep, Collection<?> values)
		throws IOException;
	
	/**
		End writing an item
		@throws IOException If there is an error
	*/
	public void endItem()
		throws IOException;
	
	/**
		End writing the document.
		@throws IOException If there is an error
	*/
	public void endDocument(ProgressReporter progress)
		throws IOException;
	
}
