/*
	$Id: CharacterEncodingFilter.java 5384 2010-08-13 08:50:27Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.servlet;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.ServletException;
import java.io.IOException;

/**
	This is a filter that sets the character encoding for both the 
	request and the response. The default encoding is UTF-8.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2010-08-13 10:50:27 +0200 (fre, 13 aug. 2010) $
*/
public final class CharacterEncodingFilter
	implements Filter
{

	private String characterEncoding = "UTF-8";
	
	@Override
	public void init(FilterConfig config)
	{
		if (config.getInitParameter("characterEncoding") != null)
		{
			characterEncoding = config.getInitParameter("characterEncoding");
		}
	}
	
	@Override
	public void destroy()
	{}
	
	@Override
	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
		throws IOException, ServletException
	{
		if (request.getCharacterEncoding() == null)
		{
			request.setCharacterEncoding(characterEncoding);
		}
		response.setContentType("text/html; charset="+characterEncoding);
		chain.doFilter(request, response);
	}
}
