/*
	$Id: HasAnnotationRestriction.java 7643 2019-03-12 07:29:06Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Martin Svensson
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.query.Query;

import org.hibernate.query.NativeQuery;

/**
	Restricts a query by the presence of absence of an annotation.
	
	@author Nicklas
	@version 2.7
	@see net.sf.basedb.core.query.Annotations
	@base.modified $Date: 2019-03-12 08:29:06 +0100 (tis, 12 mars 2019) $
*/
public class HasAnnotationRestriction
	extends AnnotationRestriction
{

	private boolean hasBeenAnnotatated;
	
	/**
		Create a new restriction that checks if an item has been annotatated
		or not.
		
		@param alias The alias of a joined item where the annotations are
			located or null to use the root entity of the query
		@param annotationType The annotation type to use in the query
		@param hasBeenAnnotatated TRUE to look for items that has been annotated with the given
			annotation type, FALSE to look for items that hasn't
		@param includePrimary If items with this annotation as a primary annotation
			should be returned by the query or not
		@param includeInheriting If items inherting the annotation should be returned
			by the query or not
		@since 3.5
		@deprecated In 3.11, use {@link #HasAnnotationRestriction(String, AnnotationType, boolean, AnnotationRestriction.Options)} instead
	*/
	@Deprecated
	public HasAnnotationRestriction(String alias, AnnotationType annotationType, 
		boolean hasBeenAnnotatated, boolean includePrimary, boolean includeInheriting)
	{
		this(alias, annotationType.getId(), hasBeenAnnotatated, includePrimary, includeInheriting);
	}
	
	/**
		Create a new restriction that checks if an item has been annotatated
		or not.
		
		@param alias The alias of a joined item where the annotations are
			located or null to use the root entity of the query
		@param annotationType The annotation type to use in the query
		@param hasBeenAnnotatated TRUE to look for items that has been annotated with the given
			annotation type, FALSE to look for items that hasn't
		@param options Options that specify which annotations to consider when searching
		@since 3.11
	*/
	public HasAnnotationRestriction(String alias, AnnotationType annotationType, 
		boolean hasBeenAnnotatated, Options options)
	{
		super(alias, annotationType, options);
		this.hasBeenAnnotatated = hasBeenAnnotatated;
	}

	
	/**
		@see #HasAnnotationRestriction(String, AnnotationType, boolean, AnnotationRestriction.Options)
		@since 3.5
		@deprecated In 3.11, use {@link #HasAnnotationRestriction(String, AnnotationType, boolean, AnnotationRestriction.Options)} instead
	*/
	@Deprecated
	public HasAnnotationRestriction(String alias, int annotationTypeId, 
		boolean hasBeenAnnotatated, boolean includePrimary, boolean includeInherited)
	{
		super(alias, annotationTypeId, null, new Options().setIncludePrimary(includePrimary).setIncludeInherited(includeInherited));
		this.hasBeenAnnotatated = hasBeenAnnotatated;
	}
	
	/*
		From the AnnotationRestriction class
		-------------------------------------------
	*/
	@Override
	String getRestrictionSql(Query query, DbControl dc)
		throws BaseException
	{
		return null;
	}
	@Override
	void setRestrictionParameters(NativeQuery<?> query)
	{}
	@Override
	boolean notAmongSelected()
	{
		return !hasBeenAnnotatated;
	}
	// -----------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	/**
		This restriction is equal to another HasAnnotationRestriction if they 
		have the same annotation type, inheritance setting and annotation check.
	*/
	@Override
	public boolean equals(Object other)
	{
		Boolean eq = maybeEquals(other);
		if (eq != null) return eq;
		HasAnnotationRestriction o = (HasAnnotationRestriction)other;
		return hasBeenAnnotatated == o.hasBeenAnnotatated;
	}
	@Override
	public int hashCode()
	{
		return super.hashCode() + (hasBeenAnnotatated ? 1 : 0);
	}
	// -------------------------------------------

}

