/*
	$Id: Transactional.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

/**
	This interface is a tagging interface for items that wants to
	be notified before a transaction is committed or after it
	has been completed or rollbacked. One example is the {@link File} item, 
	which must handle physical files on disk and check quota information. If a 
	file has been uploaded when a transaction is rolled back the file should also 
	be deleted. On the other hand, if a file item is deleted, the physical file 
	should not be deleted before {@link DbControl#commit()} is called.
	<p>
	By implementing this interface an item tells the <code>DbControl</code>
	to call the {@link BasicItem#onBeforeCommit(Transactional.Action)}, 
	{@link BasicItem#onAfterCommit(Transactional.Action)} or 
	{@link BasicItem#onRollback(Transactional.Action)} methods, whenever
	a commit is called or a rollback is required.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (mån, 06 apr. 2009) $
*/
public interface Transactional
	extends Controlled
{
	/**
		Enumeration constants used to tell the item what is going on in the core.
	*/
	public enum Action
	{
		/**
			The item is a new item and is beeing saved to the database for the first time.
		*/
		CREATE,
		
		/**
			The item is an existing item which is beeing updated.
		*/
		UPDATE,
		
		/**
			The item is an existing item which is beeing deleted.
		*/
		DELETE
	}
}
