/**
	$Id: TransactionalAction.java 5877 2011-11-16 14:39:47Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

/**
	Interface that define hooks for callbacks during transaction commit 
	and rollback. It is not allowed to use the DbControl that the
	action is part of in any of the callback methods.

	@author Nicklas
	@since 3.1
	@base.modified $Date: 2011-11-16 15:39:47 +0100 (ons, 16 nov. 2011) $
*/
public interface TransactionalAction
{

	/**
		This method is called before the commit is about to happen.
		If this method throws an exception the transaction will be
		rolled back.
	*/
	public void onBeforeCommit();
	
	/**
		Called after a successful commit. Implementations should not throw any
		exceptions from this method. If they do, the message is logged, by no
		other action is taken.
	*/
	public void onAfterCommit();
	
	/**
		Called after an unsuccessful commit. Implementations should not throw any
		exceptions from this method. If they do, the message is logged, by no
		other action is taken.
	*/
	public void onRollback();
}
