/**
	$Id: ColoringData.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	Hold coloring information. Implemented as a component since several types of
	items may be colored.
	
	@author nicklas
	@version 2.0
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (fre, 21 okt. 2011) $
	@see <a href="../../../../../../html/developer/api/data_api.misc.html">Developer documentation: Other classes</a>
*/
public class ColoringData
	implements ComponentData
{

	public ColoringData()
	{}
	
	public ColoringData(boolean useColors, boolean logarithmic, Float minValue, Float midValue, Float maxValue)
	{
		this.useColors = useColors;
		this.logarithmic = logarithmic;
		this.minValue = minValue;
		this.midValue = midValue;
		this.maxValue = maxValue;
	}
	
	private boolean useColors;

	/**
		If colors should be used or not.
		@hibernate.property column="`use_colors`" type="boolean" not-null="true"
	*/
	public boolean isUsingColors()
	{
		return useColors;
	}
	public void setUsingColors(boolean useColors)
	{
		this.useColors = useColors;;
	}
	
	private boolean logarithmic;
	/**
		If values should be logarithmised or not.
		@hibernate.property column="`logarithmic`" type="boolean" not-null="true"
	*/
	public boolean isLogarithmic()
	{
		return logarithmic;
	}
	public void setLogarithmic(boolean logarithmic)
	{
		this.logarithmic = logarithmic;
	}
	
	private Float minValue;
	/**
		The value for the minimum endpoint color.
		@hibernate.property column="`min_value`" type="float" not-null="false"
	*/
	public Float getMinValue()
	{
		return minValue;
	}
	public void setMinValue(Float minValue)
	{
		this.minValue = minValue;
	}

	private Float midValue;
	/**
		The value for the midpoint color.
		@hibernate.property column="`mid_value`" type="float" not-null="false"
	*/
	public Float getMidValue()
	{
		return midValue;
	}
	public void setMidValue(Float midValue)
	{
		this.midValue = midValue;
	}

	private Float maxValue;
	/**
		The value for the ax endpoint color.
		@hibernate.property column="`max_value`" type="float" not-null="false"
	*/
	public Float getMaxValue()
	{
		return maxValue;
	}
	public void setMaxValue(Float maxValue)
	{
		this.maxValue = maxValue;
	}

}
