/*
	$Id: MeasuredBioMaterialData.java 6468 2014-06-10 11:27:02Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class is the root class for measured biomaterials, ie biomaterials for
	where the quantity is tracked.

	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.MeasuredBioMaterial
	@see <a href="../../../../../../html/developer/api/data_api.biomaterials.html">Developer documentation: Biomaterials LIMS</a>
	@base.modified $Date: 2014-06-10 13:27:02 +0200 (tis, 10 juni 2014) $
	@hibernate.subclass discriminator-value="-2" lazy="true"
*/
public abstract class MeasuredBioMaterialData
	extends BioMaterialData
{

	public MeasuredBioMaterialData()
	{}
	
	private BioMaterialData parent;
	/**
		Get the parent biomaterial. Used when a biomaterial has a single parent item.
		@hibernate.many-to-one column="`parent_id`" not-null="false" outer-join="false"
	*/
	public BioMaterialData getParent()
	{
		return parent;
	}
	public void setParent(BioMaterialData parent)
	{
		this.parent = parent;
	}

	private Float originalQuantity;
	/**
		Get the original quantity of the biomaterial.
		@hibernate.property column="`original_quantity`" type="float" not-null="false"
	*/
	public Float getOriginalQuantity()
	{
		return originalQuantity;
	}
	public void setOriginalQuantity(Float originalQuantity)
	{
		this.originalQuantity = originalQuantity;
	}

	private Float remainingQuantity;
	/**
		Get the remaining quantity of the biomaterial.
		@hibernate.property column="`remaining_quantity`" type="float" not-null="false" update="false"
	*/
	public Float getRemainingQuantity()
	{
		return remainingQuantity;
	}
	public void setRemainingQuantity(Float remainingQuantity)
	{
		this.remainingQuantity = remainingQuantity;
	}
	
	private Integer parentType;
	/**
		Get the type of the parent item. Null if the biomaterial doesn't have any parents.
		@hibernate.property column="`parent_type`" type="int" not-null="false"
		@since 3.0
	*/
	public Integer getParentType()
	{
		return parentType;
	}
	public void setParentType(Integer parentType)
	{
		this.parentType = parentType;
	}

	private BioMaterialEventData creationEvent;
	/**
		Get the event that created this biomaterial. Mapping is defined
		in hibernate-properties-MeasuredBioMaterialData.xml since XDoclet cannot
		generate it.
	*/
	public BioMaterialEventData getCreationEvent()
	{
		return creationEvent;
	}
	void setCreationEvent(BioMaterialEventData creationEvent)
	{
		this.creationEvent = creationEvent;
	}
	
	private Set<BioMaterialEventData> events;
	/**
		This is the inverse end.
		@see BioMaterialEventData#getBioMaterial()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`biomaterial_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.BioMaterialEventData"
	*/
	Set<BioMaterialEventData> getEvents()
	{
		return events;
	}
	void setEvents(Set<BioMaterialEventData> events)
	{
		this.events = events;
	}
	
	private BioWellData bioWell;
	/**
		Get the bio well.
		@hibernate.many-to-one column="`biowell_id`" not-null="false" unique="true" outer-join="false"
	*/
	public BioWellData getBioWell()
	{
		return bioWell;
	}
	
	public void setBioWell(BioWellData bioWell)
	{
		this.bioWell = bioWell;
	}
	
}
