/*
  $Id: QuotaData.java 7015 2015-11-17 12:57:57Z nicklas $

	Copyright (C) 2005 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.HashSet;
import java.util.Set;

/**
	This file holds information about a qouta.
	
	@author enell
	@version 2.0
	@see net.sf.basedb.core.Quota
	@see <a href="../../../../../../html/developer/api/data_api.quota.html">Developer documentation: Quota and disk usage</a>
	@hibernate.class table="`Quota`" lazy="true"
	@base.modified $Date: 2015-11-17 13:57:57 +0100 (tis, 17 nov. 2015) $
*/
public class QuotaData
	extends BasicData
	implements RemovableData, NameableData, SystemData
{

	public QuotaData()
	{}
	
	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private Integer removedBy;
	@Override
	public Integer getRemovedBy()
	{
		return removedBy;
	}
	@Override
	public void setRemovedBy(Integer removedBy)
	{
		this.removedBy = removedBy;
	}
	// -------------------------------------------
	
	/*
		From the SystemItem interface
		-------------------------------------------
	*/
	private String systemId; 
	@Override
	public String getSystemId()
	{
		return systemId;
	}
	public void setSystemId(String systemId)
	{
		this.systemId = systemId;
	}
	// -------------------------------------------

	/*
		From the NameableData interface
		-------------------------------------------
	*/
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	@Override
	public void setName(String name)
	{
		this.name = name;
	}

	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------

	private Set<QuotaIndex> quotaValues;
	/**
		@hibernate.set table="`QuotaValues`" lazy="true"
		@hibernate.collection-key column="`quota_id`"
		@hibernate.collection-composite-element class="net.sf.basedb.core.data.QuotaIndex"
		@since 3.4
	*/
	public Set<QuotaIndex> getQuotaValues()
	{
		if(quotaValues == null)
		{
			quotaValues = new HashSet<QuotaIndex>();
		}
		return quotaValues;
	}
	void setQuotaValues(Set<QuotaIndex> quotaValues)
	{
		this.quotaValues = quotaValues;
	}
}
