/**
	$Id: DefaultEntityLogger.java 6351 2013-11-25 08:20:23Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log.db;

import java.util.List;

import net.sf.basedb.core.data.ChangeHistoryDetailData;
import net.sf.basedb.core.data.LoggableData;
import net.sf.basedb.core.log.EntityDetails;
import net.sf.basedb.core.log.EntityLogger;
import net.sf.basedb.core.log.LogManager;

/**
	Default logger for all entities that has been tagged with the
	{@link LoggableData} interface.

	@author Nicklas
	@version 2.13
	@base.modified $Date: 2013-11-25 09:20:23 +0100 (mån, 25 nov. 2013) $
*/
public class DefaultEntityLogger
	implements EntityLogger
{

	private final DbLogManagerFactory factory;
	private final boolean detailedProperties;
	private final boolean oldPropertyValues;
	
	/**
		Creates a new entity logger.
		@param factory The log manager factory
	*/
	public DefaultEntityLogger(DbLogManagerFactory factory)
	{
		this.factory = factory;
		this.detailedProperties = factory.isLoggingDetailedProperties();
		this.oldPropertyValues = factory.isLoggingOldPropertyValues();
	}
	
	/*
		From the EntityLogger interface
		-------------------------------
	*/
	/**
		Creates a new {@link ChangeHistoryDetailData} and saves it to
		{@link DbLogManager#logChangeDetails(ChangeHistoryDetailData, EntityDetails)}.
	*/
	@Override
	public void logChanges(LogManager logManager, EntityDetails details)
	{
		DbLogManager dbLogManager = (DbLogManager)logManager;
		List<ChangeHistoryDetailData> changes = details.toChangeDetails(detailedProperties, oldPropertyValues);
		dbLogManager.logChangeDetails(changes, details);
	}
	// -------------------------------
}
