/*
	$Id $

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import net.sf.basedb.core.Item;
import net.sf.basedb.util.filter.Filter;

/**
	Filter implementation that checks if the items
	returned by a {@link EntityQuery} are compatible
	with the specified class. Intended to be used
	with a conditiona restriction or expression as
	created by {@link Restrictions#conditionalRestriction(Filter, Restriction, Restriction, boolean)}
	and {@link Expressions#conditionalExpression(Filter, Expression, Expression)}
	
	@author nicklas
	@since 3.7
*/
public class ReturnClassFilter 
	implements Filter<EntityQuery>
{
	
	private final Class<?> returnClass;
	
	/**
		Creates a filter that matches the specified item class.
	*/
	public ReturnClassFilter(Class<?> returnClass)
	{
		this.returnClass = returnClass;
	}
	
	/**
		Returns TRUE if the {@link EntityQuery#getItemType()} returns
		an item type whose {@link Item#getItemClass()} is compatible with
		the specified class.
	 */
	@Override
	public boolean evaluate(EntityQuery query)
	{
		return returnClass.isAssignableFrom(query.getItemType().getItemClass());
	}

}
