/*
	$Id: DynamicFilter.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import net.sf.basedb.core.BioAssaySet;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Job;
import net.sf.basedb.core.ProgressReporter;
import net.sf.basedb.core.query.SqlQuery;
import net.sf.basedb.core.query.SqlResult;

import java.sql.SQLException;
import java.util.List;

/**
	This interface is used together with the <code>BioAssaySetFilterUtil</code>
	class to help a plugin filter the data of a bioassay set. A plugin
	must supply an implementation of this interface to be able to use the
	{@link BioAssaySetFilterUtil#createFilteredBioAssaySet(DbControl, BioAssaySet, 
	List, Job, DynamicFilter, ProgressReporter)}
	method.
	
	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (mån, 06 apr. 2009) $
*/
public interface DynamicFilter
{
	/**
		Configure the query before it is used. This includes selecting any
		columns that is needed by the {@link #includeSpot(SqlResult)} method
		later and joining related tables (ie. raw data, reporter) that is needed
		by the filter.
		@param query The query to configure
	*/
	public void configureQuery(SqlQuery query);
	
	/**
		If the <code>includeSpot</code> method must be called for each spot or not.
		If FALSE is returned, all rows that are returned by the query are included in 
		the filtered bioassay set.
		
		@return TRUE or FALSE
	 */
	public boolean useIncludeSpot();
	
	/**
		Check if a spot should be included in the filtered output or not.
		
		@param data The current data row to check
		@return TRUE if the spot passed the filter, FALSE otherwise
		@throws SQLException If running SQL statement fails.
	*/
	public boolean includeSpot(SqlResult data)
		throws SQLException;
}
