/**
	$Id: FilenameGenerator.java 5212 2010-01-12 13:21:49Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

/**
	File name generators are used together with {@link DataWriterFactory}
	implementations to generate file names for BFS data files.

	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-12 14:21:49 +0100 (tis, 12 jan. 2010) $
*/
public interface FilenameGenerator<T>
{

	/**
		Get the next file name. This method should never return
		the same file name more than one time (given a single
		implementor instance). The generator implementation should not
		concern itself with the underlying file system or if the file
		already exists or not (this is a task for the {@link DataWriterFactory}
		implementation). 
		
		@param owner The owner of the data in the file
		@param suggestedFilename A default suggested file name (can be null)
		@return A unique file name
	*/
	public String getNextFilename(T owner, String suggestedFilename);

}
