/**
	$Id: WrappingRenderer.java 4870 2009-04-01 11:38:59Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions;

/**
	An extension to the regular renderer interface 
	intended for renderers that wants to wrap an existing
	renderer to give the result their own touch.

	@author nicklas
	@version 2.12
	@base.modified $Date: 2009-04-01 13:38:59 +0200 (ons, 01 apr. 2009) $
*/
public interface WrappingRenderer<A extends Action>
	extends Renderer<A>
{

	/**
		Set a parent renderer. Some implementations may 
		have restrictions on this method. For example,
		they may not allow a parent renderer to be set after 
		the object has been constructed, or they may not
		allow the parent to be set to null, etc.
		
		@param parent The parent renderer that should be
			wrapped by this renderer
		@throws UnsupportedOperationException If the implementation
			doesn't support this method
	*/
	public void setParent(Renderer<? super A> parent);
	
	/**
		Get the current parent renderer.
		@return A renderer or null if there is no
			parent
	*/
	public Renderer<? super A> getParent();
	
}
