/**
	$Id: StringConverter.java 6875 2015-04-20 09:08:18Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.debug;

import java.util.HashMap;
import java.util.Map;

import net.sf.basedb.core.Type;

/**
	Convert strings to other data types. This class is experimental
	only and may change in the future.

	@author nicklas
	@version 2.7
	@base.modified $Date: 2015-04-20 11:08:18 +0200 (mån, 20 apr. 2015) $
*/
public class StringConverter
{
	
	private static Map<Class<?>, StringConverter> converter;
	
	static
	{
		converter = new HashMap<Class<?>, StringConverter>();
		converter.put(int.class, new StringConverter(Type.INT, 0));
		converter.put(Integer.class, new StringConverter(Type.INT, null));
		converter.put(long.class, new StringConverter(Type.LONG, 0l));
		converter.put(Long.class, new StringConverter(Type.LONG, null));
		converter.put(float.class, new StringConverter(Type.FLOAT, 0f));
		converter.put(Float.class, new StringConverter(Type.FLOAT, null));
		converter.put(double.class, new StringConverter(Type.DOUBLE, 0d));
		converter.put(Double.class, new StringConverter(Type.DOUBLE, null));
		converter.put(boolean.class, new StringConverter(Type.BOOLEAN, false));
		converter.put(Boolean.class, new StringConverter(Type.BOOLEAN, null));
		converter.put(String.class, new StringConverter(Type.STRING, null));
	}
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	public static Object convertString(Class toClass, String value)
	{
		StringConverter c = converter.get(toClass);
		if (c == null && toClass.isEnum())
		{
			try
			{
				return Enum.valueOf(toClass, value);
			}
			catch (RuntimeException ex)
			{}
		}
		return c == null ? null : c.convert(value);
	}
	
	private final Type type;
	private final Object defaultValue;
	
	private StringConverter(Type type, Object defaultValue)
	{
		this.type = type;
		this.defaultValue = defaultValue;
	}
	
	private Object convert(String value)
	{
		if (value == null) return defaultValue;
		return type.parseString(value);
	}
	
}
