/**
	$Id: SingleFileValidationAction.java 5623 2011-05-06 12:09:13Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.fileset;

import net.sf.basedb.core.DataFileType;
import net.sf.basedb.core.FileSetMember;

/**
	Base class for validators that works on single files
	of a known data file type. The external if of the 
	file type should be specified in the constructor.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-05-06 14:09:13 +0200 (fre, 06 maj 2011) $
*/
public abstract class SingleFileValidationAction
	implements ValidationAction
{

	private final String fileTypeId;
	private FileSetMember acceptedFile;
	
	/**
		Create a new instance.
		
		@param fileTypeId The external if of the {@link DataFileType}
			that this validator supports
	*/
	protected SingleFileValidationAction(String fileTypeId)
	{
		this.fileTypeId = fileTypeId;
	}

	/*
		From the ValidationAction interface
		-----------------------------------
	*/
	/**
		If the file has a file type matching the id given in the constructor
		it is accepted for immediate validation. 
		@return {@link Accept#VALIDATE_IMMEDIATELY} or null
	*/
	@Override
	public Accept acceptFile(FileSetMember member)
	{
		DataFileType fileType = member.getDataFileType();
		if (fileType.getExternalId().equals(fileTypeId))
		{
			this.acceptedFile = member;
			return Accept.VALIDATE_IMMEDIATELY;
		}
		this.acceptedFile = null;
		return null;
	}
	// -----------------------------------

	/**
		Get the file that was last accepted by the {@link #acceptFile(FileSetMember)}
		method.
		@return A file set member object, or null if the last file was not accepted
	*/
	protected FileSetMember getAcceptedFile()
	{
		return acceptedFile;
	}

}
