package net.sf.basedb.util.formatter;

import java.util.Collection;

import net.sf.basedb.util.Values;

/**
	Formatter implementation that formats a collection of values to a
	string by concatenating the values with a given separator.
	Reverse parsing is not supported.
	
	@author nicklas
	@since 3.16
*/
public class CollectionFormatter<I>
	implements Formatter<Collection<I>>
{
	
	private final Formatter<? super I> parent;
	private final String separator;
	private final boolean skipNull;
	
	/**
		Create a collection formatting using ", " as separator and skipping null values.
	*/
	public CollectionFormatter(Formatter<? super I> parent)
	{
		this(", ", true, parent);
	}
	
	public CollectionFormatter(String separator, boolean skipNull, Formatter<? super I> parent)
	{
		this.parent = parent;
		this.separator = separator;
		this.skipNull = skipNull;
	}

	@Override
	public String format(Collection<I> values) 
	{
		return Values.getString(values, separator, skipNull, parent);
	}

	@Override
	public Collection<I> parseString(String value) 
	{
		throw new UnsupportedOperationException("parseString");
	}
		
}
