/**
	$Id: ItemTypeFormatter.java 5664 2011-06-23 09:53:05Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.formatter;

import net.sf.basedb.core.Item;

/**
	Formatter implementation that converts an integer into it's Item
	representation and the uses name() as the formatted value.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-06-23 11:53:05 +0200 (tors, 23 juni 2011) $
*/
public class ItemTypeFormatter
	implements Formatter<Integer>
{
	private String nullValue = "";

	/**
		Create a new formatter. Null values are formatted as an empty string.
	*/
	public ItemTypeFormatter()
	{}

	/**
		Create a new formatter.
		@param nullValue The string to return if a null item is 
			passed to {@link #format(Integer)}
	*/
	public ItemTypeFormatter(String nullValue)
	{
		this.nullValue = nullValue;
	}

	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(Integer value)
	{
		Item item = value == null ? null : Item.fromValue(value);
		return item == null ? nullValue : item.name(); 
	}

	@Override
	public Integer parseString(String value)
	{
		try
		{
			return Item.valueOf(value).getValue();
		}
		catch (Exception ex)
		{}
		return null;
	}
	// -------------------------------------------
		
	
	
}
