/**
	$Id: NameableFormatter.java 4925 2009-05-08 11:30:36Z nicklas $

	Copyright (C) 2009 Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.formatter;

import net.sf.basedb.core.Nameable;

/**
 	Formatter to handle {@link Nameable} items.
  	@author martin
  	@version 2.12
  	@base.modified $Date: 2009-05-08 13:30:36 +0200 (fre, 08 maj 2009) $
 */
public class NameableFormatter 
	implements Formatter<Nameable>
{
	private String nullValue = "";

	/**
		Create a new formatter. Null values are formatted as an empty string.
	*/
	public NameableFormatter()
	{}
	
	/**
		Create a new formatter.
		@param nullValue The string to return if a null item is 
			passed to {@link #format(Nameable)}
	*/
	public NameableFormatter(String nullValue)
	{
		this.nullValue = nullValue;
	}
	
	/*
		From the Formatter interface
		-------------------------------------------
	*/
	@Override
	public String format(Nameable nameableItem)
	{		
		return nameableItem == null ? nullValue : nameableItem.getName();
	}

	/**
		@throws UnsupportedOperationException Always
	*/
	@Override
	public Nameable parseString(String value)
	{
		throw new UnsupportedOperationException("parseString: " + value);
	}
	// -------------------------------------------

}
