/**
	$Id: ASTVarNodeConverter.java 4515 2008-09-11 20:08:14Z jari $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep.convert;

import net.sf.basedb.core.query.Expression;
import net.sf.basedb.core.query.Expressions;

import org.nfunk.jep.ASTVarNode;

/**
	Converts a variable node to a parameter expression or null.

	@author nicklas
	@version 2.4
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (tors, 11 sep. 2008) $
*/
public class ASTVarNodeConverter
	extends AbstractJepConversionFunction<ASTVarNode>
{
	
	public ASTVarNodeConverter()
	{}
	
	/*
		From the JepConversionFunction interface
		-------------------------------------------
	*/
	/**
		Converts a JEP variable to a parameter. A value for the parameter
		must be set on the query before executing it. The special variable
		<code>NULL</code> (ignoring case) is converted to Java null.
		@return An {@link Expression} representing a parameter or null
		@see net.sf.basedb.core.query.Query#setParameter(String, Object, net.sf.basedb.core.Type)
	*/
	@Override
	public Expression toExpression(ASTVarNode node)
	{
		Expression e = null;
		String name = node.getName();
		if ("NULL".equalsIgnoreCase(name)) name = null;
		return name == null ? null : Expressions.parameter(name);
	}
	// -------------------------------------------

}
