/**
	$Id: AnyToAnyLoader.java 6959 2015-10-01 09:37:58Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;


import net.sf.basedb.core.AnyToAny;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.ItemResultIterator;
import net.sf.basedb.core.RootRawBioAssay;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.AnyToAnyNameGenerator;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for any-to-any links. The links are
	loaded as an end-point folder node with one child entry
	for each link. It can never be root node or a forward/reverse-loading 
	node.

	@author Nicklas
	@since 2.17
	@base.modified $Date: 2015-10-01 11:37:58 +0200 (tors, 01 okt. 2015) $
*/
public class AnyToAnyLoader
	extends BasicItemNodeLoader<AnyToAny>
{

	public AnyToAnyLoader()
	{
		super(Item.ANYTOANY, DENY_ROOT_NODE, new AnyToAnyNameGenerator());
	}

	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		
		NodeFactory<AnyToAny> nf = getNodeFactory(dc, context);
		Node folderNode = null;
		
		// Load all any-to-any links for the give item
		BasicItem parent = parentNode.getItem(dc);
		if (parent instanceof RootRawBioAssay)
		{
			// The parent may be a root raw bioasay if the overview starts at the
			// experiment level
			parent = ((RootRawBioAssay)parent).getRawBioAssay();
		}

		ItemQuery<AnyToAny> query = context.initQuery(AnyToAny.getLinksFrom(parent), "name");

		ItemResultIterator<AnyToAny> it = query.iterate(dc);
		while (it.hasNext())
		{
			if (folderNode == null)
			{
				folderNode = new Node("any", "Other related items", parentNode, ChildNodeDirection.NONE);
			}
			AnyToAny any = it.next();
			createItemNode(nf, any, null, false, folderNode, ChildNodeDirection.NONE);
		}
		postValidateFolder(nf, folderNode, parentNode, false);
		return folderNode;
	}
	// --------------------------------
}
