/**
	$Id: NameableNameGenerator.java 5651 2011-06-08 13:00:33Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.node;

import net.sf.basedb.core.Nameable;
import net.sf.basedb.util.overview.Node;

/**
	Name generator implementation for {@link Nameable}
	items. The name and title can each have two variants,
	depending on the node type of the parent node.
	If the parent node is a folder-type node, the name
	is generated as <code>prefix.item-id</code> and the
	title is the name of the item, eg. {@link Nameable#getName()}.
	<p>
	If the parent node is an item-type node, the name
	is only the namePrefix and the title is the title 
	prefix combined with the name of the item.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-06-08 15:00:33 +0200 (ons, 08 juni 2011) $
*/
public class NameableNameGenerator<I extends Nameable>
	implements NodeNameGenerator<I>
{

	private String namePrefix;
	private String titlePrefix;
	
	/**
		Create a new name generator.
		@param namePrefix The prefix to use in node names
		@param titlePrefix The prefix to use in node titles
	*/
	public NameableNameGenerator(String namePrefix, String titlePrefix)
	{
		this.namePrefix = namePrefix;
		this.titlePrefix = titlePrefix;
	}
	
	@Override
	public String getNodeName(I item, Node parentNode)
	{
		StringBuilder name = new StringBuilder(namePrefix);
		if (parentNode != null && parentNode.getNodeType() == Node.Type.FOLDER)
		{
			name.append(".").append(item.getId());
		}
		return name.toString();
	}

	@Override
	public String getNodeTitle(I item, Node parentNode)
	{
		StringBuilder title = new StringBuilder();
		if (parentNode != null && parentNode.getNodeType() == Node.Type.ITEM)
		{
			if (titlePrefix != null) title.append(titlePrefix).append(": ");
		}
		title.append(item.getName());
		return title.toString();
	}

	@Override
	public String getDeniedNodeName(Node parentNode)
	{
		return namePrefix;
	}

	@Override
	public String getDeniedNodeTitle(Node parentNode)
	{
		return titlePrefix + ": denied";
	}

	@Override
	public String getMissingNodeName(Node parentNode)
	{
		return namePrefix;
	}

	@Override
	public String getMissingNodeTitle(Node parentNode)
	{
		return titlePrefix + ": missing";
	}

}
