/**
	$Id: BioSourceValidator.java 5689 2011-08-11 09:09:06Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.BioSource;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.Node;

/**
	Validator implementation for biosources. Validation rules:
	<ul>
	<li>Missing item: {@link Validator#MISSING_BIOSOURCE}
	<li>Access denied: {@link Validator#DENIED_BIOSOURCE}
	</ul>

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-08-11 11:09:06 +0200 (tors, 11 aug. 2011) $
*/
public class BioSourceValidator
	extends NameableNodeValidator<BioSource>
{
	
	public BioSourceValidator()
	{
		super(Validator.MISSING_BIOSOURCE, Validator.DENIED_BIOSOURCE);
	}

	/* 
		From BasicValidator class
		-------------------------
	*/
	@Override
	public void postValidate(DbControl dc, OverviewContext context, Node node, Node parentNode) 
	{
		super.postValidate(dc, context, node, parentNode);

		// If parent node contains a sample, check the subtypes
		if (parentNode != null && parentNode.getItemType() == Item.SAMPLE)
		{
			SampleValidator.checkParentBioSourceSubtype(dc, context, parentNode, node);
		}
	}
	
	/**
		@return Suggested fix is to add a biosource to the parent sample.
	*/
	@Override
	protected Fix getMissingItemFix(DbControl dc, Node sampleNode)
	{
		return new Fix("Add biosource to sample", sampleNode.getItem());
	}
	// ----------------------------
	
}
