/**
	$Id: HttpConnectionManagerActionFactory.java 6875 2015-04-20 09:08:18Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.uri.http;

import net.sf.basedb.core.plugin.About;
import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.Extension;
import net.sf.basedb.util.extensions.ExtensionsUtil;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.uri.ConnectionManagerFactory;

/**
	Action factory for http connection manager factory. This factory
	will create a singleton instance of {@link HttpConnectionManagerFactory}
	upon the first use. This instance will be used for all further
	uses of this extension.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2015-04-20 11:08:18 +0200 (mån, 20 apr. 2015) $
*/
public class HttpConnectionManagerActionFactory
	implements ActionFactory<ConnectionManagerFactory>
{
	
	private volatile HttpConnectionManagerFactory factory;
	
	public HttpConnectionManagerActionFactory()
	{}
	
	/*
		From the ActionFactory interface
		---------------------------------
	*/
	@Override
	public boolean prepareContext(
			InvokationContext<? super ConnectionManagerFactory> context)
	{
		return true;
	}
	
	@Override
	public ConnectionManagerFactory[] getActions(
			InvokationContext<? super ConnectionManagerFactory> context)
	{
		if (factory == null)
		{
			initFactory(context);
		}
		return new ConnectionManagerFactory[] { factory };
	}
	// --------------------------------------------
	
	private synchronized void initFactory(InvokationContext<? super ConnectionManagerFactory> context)
	{
		if (factory != null) return;
		Extension<?> ext = context.getExtension();
		About about = ext.getAbout();
		
		String id = ext.getId();
		String name = ExtensionsUtil.getName(ext);
		String description = about != null ? about.getDescription() : null;
		
		HttpConnectionManagerFactory tmp = new HttpConnectionManagerFactory();
		tmp.init(id, name, description);
		factory = tmp;
	}
	
}
