/**
	$Id: PackUtil.java 5758 2011-09-23 07:05:23Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.zip;

import net.sf.basedb.core.File;
import net.sf.basedb.core.ItemSubtype;

/**

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-09-23 09:05:23 +0200 (fre, 23 sep. 2011) $
*/
public class PackUtil
{

	/**
		Copy certain properties from the archive file to the unpacked
		file. Only properies that have been set on the archive
		file are copied.
		
		<ul>
		<li>Description
		<li>Character set (only if the MIME type on the unpacked file start with 'text/')
		<li>Item subtype
		<li>Write protected flag
		</ul>
		
		@param archive The master archive (or null if not known)
		@param unpacked The file that is being unpacked
		@since 3.0
	*/
	public static void copyProperties(File archive, File unpacked)
	{
		if (archive == null) return;
		
		// Description
		String description = archive.getDescription();
		if (description != null) unpacked.setDescription(description);
		
		// Character set
		String characterSet = archive.getCharacterSet();
		String mimeType = unpacked.getMimeType();
		if (characterSet != null && mimeType != null && mimeType.startsWith("text/"))
		{
			unpacked.setCharacterSet(archive.getCharacterSet());
		}
		
		// Subtype
		try
		{
			ItemSubtype subtype = archive.getItemSubtype();
			if (subtype != null) unpacked.setItemSubtype(subtype);
		}
		catch (Exception ex)
		{}
		
		// Write protected
		unpacked.setWriteProtected(archive.isWriteProtected());
		
	}
	
}
