/**
	$Id: GtfReporterImporter.java 5770 2011-09-29 11:27:33Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.plugins.gtf;

import java.io.IOException;
import java.io.InputStream;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.core.plugin.ParameterValues;
import net.sf.basedb.plugins.ReporterFlatFileImporter;
import net.sf.basedb.util.InputStreamTracker;
import net.sf.basedb.util.gtf.GtfInputStream;
import net.sf.basedb.util.parser.FlatFileParser;
import net.sf.basedb.util.parser.WrappedConfigureByExample;


/**
	Reporter importer implementation that create reporters from information
	in GTF files. The implementation builds on the regular 
	{@link ReporterFlatFileImporter} but uses a {@link GtfInputStream}
	as a wrapper to generate a pure column-based output which can be used
	by the regular tools for file parsing. The importer will also skip
	lines with a non-unique transcript_id+seqname.
	<p>
	
	The default configuration is to use the transcript_id+seqname as the reporter id
	and name. gene_id is stored as "gene symbol" and seqname as "chromosome". 
	The default configuration can be changed by user configurations depending on 
	what additional attributes that are present in the GTF file.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-09-29 13:27:33 +0200 (tors, 29 sep. 2011) $
*/
public class GtfReporterImporter
	extends ReporterFlatFileImporter
	implements WrappedConfigureByExample
{

	public GtfReporterImporter()
	{}
	
	/**
		Needed for progress reporting since reading from the source
		will produce less bytes when wrapped.
	*/
	private InputStreamTracker tracker;

	/*
		From the Plugin interface
		-------------------------------------------
	*/
	@Override
	public void init(SessionControl sc, ParameterValues configuration,
			ParameterValues job) throws BaseException
	{
		// Wrapper that provides default values for a configuration
		configuration = new DefaultConfigurationValues(configuration);
		super.init(sc, configuration, job);
	}
	// -------------------------------------------
	
	/*
		From the WrappedConfigureByExample interface
		-------------------------------------------
	*/
	/**
		Wrap the input stream with a {@link GtfInputStream}.
	*/
	@Override
	public InputStream wrapInputStream(InputStream in)
		throws IOException
	{
		tracker = new InputStreamTracker(in);
		return new GtfInputStream(tracker, getCharset(), true);
	}
	// -------------------------------------------

	/**
		Get the number of bytes read from the original file.
	*/
	@Override
	protected long getNumBytes(FlatFileParser ffp)
	{
		return tracker.getNumRead();
	}

}
