/**
	$Id: Config.java 4514 2008-09-11 20:07:12Z jari $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.test.performance;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Properties;

import net.sf.basedb.core.ConfigurationException;

/**

	@author nicklas
	@version 2.4
	@base.modified $Date: 2008-09-11 22:07:12 +0200 (tors, 11 sep. 2008) $
*/
public class Config
{

	/**
		Variable for holding the configuration properties.
	*/
	private static Properties config = null;

	/**
		Loads the settings from the configuration file.
		@throws ConfigurationException This exception is thrown if the
			configuration settings cannot be loaded
	*/
	public static synchronized void init()
		throws ConfigurationException
	{
		try
		{
			URL testConfig = Config.class.getResource("/performance.properties");
			InputStream is = testConfig == null ? null : testConfig.openStream();
			if (is == null)
			{
				throw new ConfigurationException("Can't find the properties file. Make sure '/performance.properties' is in the CLASSPATH.");
			}
			config = new Properties();
			config.load(is);
			is.close();
		}
		catch (IOException ex)
		{
			config = null;
			throw new ConfigurationException("Error while loading properties from '/performance.properties'. " + ex.getMessage());
		}
	}
		
	
	/**
		Get the name of the formula to use for calculating the root bioassay set.
		Reads the setting <code>intensity.rawdatatype</code> from the configuration 
		file.
		@param rawDataType The ID of the raw data type
		@return The name of the formula
	*/
	public static String getIntensityFormula(String rawDataType)
	{
		return get("intensity."+rawDataType);
	}
	
	/**
		Get the JEP expression to use for filtering a bioassay set.
		Reads the setting <code>filter.expression</code> from the configuration 
		file.
		@return The filter expression
	*/
	public static String getFilterExpression()
	{
		return get("filter.expression");
	}
	
	public static String get(String key)
	{
		if (config == null) init();
		return config.getProperty(key);
	}
	
}
