/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var JobAgents = function()
{
	var agents = {};
	
	/**
		Initialize the page.
	*/
	agents.initPage = function()
	{
		var pageId = Doc.getPageId();		
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', agents.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', agents.validateJobAgent);
			
			// Port number
			Events.addEventHandler('port', 'keypress', Events.integerOnly);
			Buttons.addClickHandler('useDefaultPort', agents.setPortNumber);
			
			// Plugin settings
			agents.pluginSettings = Data.json('page-data', 'plugin-settings');
			
			Events.addEventHandler('plugins', 'click', agents.pluginsOnClick);
			Events.addEventHandler('plugins', 'base-selected', agents.pluginsOnClick);
			Events.addEventHandler('btnRemovePlugins', 'click', agents.hidePluginSettings);

			Events.addEventHandler('maxMemory', 'blur', agents.maxMemoryOnBlur);
			Events.addEventHandler('useDefaultMaxMemory', 'click', agents.useDefaultMaxMemoryOnClick)
			Events.addEventHandler('trustedDefault', 'click', agents.trustedOnClick);
			Events.addEventHandler('trustedYes', 'click', agents.trustedOnClick);
			Events.addEventHandler('trustedNo', 'click', agents.trustedOnClick);
			Events.addEventHandler('priorityBoost', 'keypress', Events.integerOnly);
			Events.addEventHandler('priorityBoost', 'blur', agents.priorityBoostOnBlur);
			
			var selectedPlugin = Data.get('page-data', 'select-plugin');
			if (selectedPlugin) agents.selectPlugin(selectedPlugin);

		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'JOBAGENT', 'item-id': itemId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnPause', agents.controlJobAgent, tableAttributes);
			Buttons.addClickHandler('btnStart', agents.controlJobAgent, tableAttributes);
			
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'JOBAGENT'};
			var tableAttributes = {'table-id': 'agents'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnPause', agents.controlJobAgents, tableAttributes);
			Buttons.addClickHandler('btnStart', agents.controlJobAgents, tableAttributes);
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}

	// Add event handlers to the 'configure plugin settings' icons
	agents.initElements = function(element, autoInit)
	{
		if (autoInit == 'configure-plugin')
		{
			Buttons.addClickHandler(element, agents.configurePlugin);
		}
	}

	agents.controlJobAgent = function(event)
	{
		var cmd = Data.get(event.currentTarget, 'action');
		var itemId = Data.get(event.currentTarget, 'item-id');
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd='+cmd+'&item_id='+itemId;
		location.replace(url);
		Table.submitSelected('agents', cmd);
	}

	agents.controlJobAgents = function(event)
	{
		var cmd = Data.get(event.currentTarget, 'action');
		Table.submitSelected('agents', cmd);
	}
	
	agents.configurePlugin = function(event)
	{
		var itemId = Data.get('page-data', 'item-id');
		var pluginId = Data.get(event.currentTarget, 'plugin-id');
		Items.editItem('JOBAGENT', itemId, '&plugin_id='+pluginId);
	}
	
	agents.validateJobAgent = function()
	{
		var frm = document.forms['agent'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		else if (Strings.trim(frm.external_id.value) == '')
		{
			Forms.showNotification(frm.external_id, 'You must enter an external ID');
			return false;
		}
		else if (Strings.trim(frm.port.value) != '')
		{
			var port = parseInt(frm.port.value);
			if (port < 1 || port > 65535)
			{
				Forms.showNotification(frm.port, 'The port value must be between 1 and 65535');
				return false;
			}
		}
		return true;
	}

	agents.save = function()
	{
		var frm = document.forms['agent'];
		if (TabControl.validateActiveTab('settings'))
		{
			Link.exportActions('plugins');
			var plugins = Link.getIdsInList(frm.plugins, 'PLUGINDEFINITION');
			for (var i = 0; i < plugins.length; i++)
			{
				var pluginId = plugins[i];
				var settings = agents.getPluginSettings(pluginId);
				if (settings)
				{
					if (settings.maxMemory)
					{
						Forms.addHidden(frm, 'maxMemory.'+pluginId, settings.maxMemory);
					}
					Forms.addHidden(frm, 'trusted.'+pluginId, settings.trusted);					
					Forms.addHidden(frm, 'priorityBoost.'+pluginId, settings.priorityBoost);
				}
			}
			Forms.addHidden(frm, 'allPlugins', plugins.join(','));
			frm.submit();
		}
	}

	agents.setPortNumber = function(event)
	{
		var frm = document.forms['agent'];
		frm.port.value = Data.get(event.currentTarget, 'port');
	}

	agents.getPluginSettings = function(pluginId)
	{
		for (var i = 0; i < agents.pluginSettings.length; i++)
		{
			if (agents.pluginSettings[i].pluginId == pluginId)
			{
				return agents.pluginSettings[i];
			}
		}
		return null;
	}
	
	agents.selectPlugin = function(pluginId)
	{
		var frm = document.forms['agent'];
		for (var i = 0; i < frm.plugins.length; i++)
		{
			if (frm.plugins[i].item.id == pluginId)
			{
				frm.plugins.selectedIndex = i;
				agents.pluginsOnClick();
				return;
			}
		}
	}

	
	/**
		When selecting a plugin in the list, the
		settings for it should be displayed.
	 */
	agents.pluginsOnClick = function()
	{
		var frm = document.forms['agent'];
		var settings;
		if (frm.plugins.selectedIndex >= 0)
		{
			var item = frm.plugins[frm.plugins.selectedIndex].item;
			var pluginId = item ? item.id : null;
			settings = agents.getPluginSettings(pluginId);
		}
		
		if (settings)
		{
			Doc.show('pluginsettings');
			// Set max memory
			frm.useDefaultMaxMemory.checked = !settings.maxMemory;
			frm.maxMemory.value = settings.maxMemory || '';
			frm.maxMemory.disabled = frm.useDefaultMaxMemory.checked;
			
			var defaultMaxMemory = Doc.element('defaultMaxMemory');
			defaultMaxMemory.innerHTML = settings.defaultMaxMemory || '<i>not specified</i>';
			
			// Set trusted
			Forms.checkRadio(frm.trusted, settings.trusted);
			var defaultTrusted = Doc.element('defaultTrusted');
			defaultTrusted.innerHTML = settings.defaultTrusted ? 'yes' : 'no';

			// Set priority boost
			frm.priorityBoost.value = settings.priorityBoost;
		}
		else
		{
			Doc.hide('pluginsettings');
		}
	}
	
	agents.hidePluginSettings = function()
	{
		Doc.hide('pluginsettings');
	}
	
	agents.maxMemoryOnBlur = function()
	{
		var frm = document.forms['agent'];
		var pluginId = frm.plugins[frm.plugins.selectedIndex].item.id;
		var settings = agents.getPluginSettings(pluginId);
		if (settings)
		{
			settings.maxMemory = frm.maxMemory.value;
		}
	}
	
	agents.useDefaultMaxMemoryOnClick = function()
	{
		var frm = document.forms['agent'];
		var pluginId = frm.plugins[frm.plugins.selectedIndex].item.id;
		var settings = agents.getPluginSettings(pluginId);
		if (settings)
		{
			var useDefault = frm.useDefaultMaxMemory.checked;
			
			settings.maxMemory = useDefault ? null : frm.maxMemory.value;
			frm.maxMemory.disabled = useDefault;
			if (!frm.maxMemory.disabled) frm.maxMemory.focus();
		}
	}

	
	agents.trustedOnClick = function()
	{
		var frm = document.forms['agent'];
		var pluginId = frm.plugins[frm.plugins.selectedIndex].item.id;
		var settings = agents.getPluginSettings(pluginId);
		
		if (settings)
		{
			var selected = Forms.getCheckedRadio(frm.trusted);
			if (selected != null)
			{
				settings.trusted = selected.value;
			}
		}
	}

	agents.priorityBoostOnBlur = function()
	{
		var frm = document.forms['agent'];
		var pluginId = frm.plugins[frm.plugins.selectedIndex].item.id;
		var settings = agents.getPluginSettings(pluginId);
		
		if (settings)
		{
			var priorityBoost = parseInt(frm.priorityBoost.value);
			if (priorityBoost < 0 || priorityBoost > 10)
			{
				Forms.showNotification(frm.priorityBoost, 'The priority boost must be between 0 and 10');
				return;
			}
			settings.priorityBoost = priorityBoost;
		}
	}
	
	return agents;
}();

Doc.addElementInitializer(JobAgents.initElements);
Doc.onLoad(JobAgents.initPage);
