/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var FileManager = function()
{
	var fileManager = {};
	var tableAttributes = {'table-id': 'files', 'item-type': 'FILE'};
	
	/**
		Initialize the page.
	*/
	fileManager.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', fileManager.save);
			Buttons.addClickHandler('close', App.closeWindow);
			
			// Tab validation
			TabControl.addTabValidator('settings.info', fileManager.validateFile);

			// MIME type
			Buttons.addClickHandler('selectMimeType', fileManager.selectMimeType);
			Events.addEventHandler('selectMimeType', 'base-selected', fileManager.setMimeTypeCallback);

			// Select fileserver
			Buttons.addClickHandler('server_id.select', fileManager.selectFileServer);
			Events.addEventHandler('server_id', 'base-selected', Items.onItemSelected);
			
			// URL
			Events.addEventHandler('url', 'change', fileManager.urlOnChange);
			Events.addEventHandler('url', 'keyup', fileManager.urlOnChange);
			
		}
		else if (pageId == 'view-page')
		{
			var fileController = Items.getController('FILE');
			fileController.url = 'filemanager/files/index.jsp';
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'FILE', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
			Buttons.addClickHandler('btnCompress', fileManager.compressFile, attributes);
			Buttons.addClickHandler('btnDecompress', fileManager.decompressFile, attributes);
			Buttons.addClickHandler('btnEditFileData', fileManager.editFileData, attributes);
			Buttons.addClickHandler('moveOffline', fileManager.moveToLocation);
			
			TabControl.addTabActivateListener('main.history', History.loadOnce);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'FILE'};
			
			var fileController = Items.getController('FILE');
			fileController.url = 'filemanager/files/index.jsp';
			
			Buttons.addClickHandler('btnNewDirectory', Buttons.newItem);
			Buttons.addClickHandler('btnUpload', fileManager.uploadFile);
			Buttons.addClickHandler('btnNewURL', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnEditMultipleFiles', fileManager.editMultipleFiles);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
			
			Events.addEventHandler('mnuMoveToDirectory', 'click', fileManager.selectDirectory);
			Events.addEventHandler('mnuMoveToDirectory', 'base-selected', fileManager.moveToDirectory);
			Events.addEventHandler('mnuMoveOffline', 'click', fileManager.moveToLocation);
			
			Events.addEventHandler('reloadOnNotify', 'base-notify', App.reloadWindow);
						
			if (Data.int('page-data', 'is-search'))
			{
				var numFiles = Data.int('page-data', 'files-found');
				var numDirectories = Data.int('page-data', 'directories-found');
				parent.frames.directories.Directories.updateSearchResults(numFiles, numDirectories);
			}
			
			var frm = document.forms['files'];
			var mode = frm.mode ? frm.mode.value : 'default';
			if (mode == 'selectone')
			{
				var path = Data.get('page-data', 'current-path');
				if (path)
				{
					window.top.SelectFile.setSelectedDirectory(frm.directory_id.value, path);
				}
			}
			
		}
	}

	fileManager.initElements = function(element, autoInit)
	{
		if (autoInit == 'upload-file')
		{
			Buttons.addClickHandler(element, fileManager.uploadFile);
		}
		else if (autoInit == 'open-directory')
		{
			Buttons.addClickHandler(element, fileManager.openDirectory);
		}
		else if (autoInit == 'file-item')
		{
			Events.addEventHandler(element, 'click', fileManager.onFileSelected, tableAttributes);
		}
		else if (autoInit == 'file-check')
		{
			Events.addEventHandler(element, 'change', fileManager.onFileChecked);
			if (element.checked) Events.sendChangeEvent(element);
		}
		else if (autoInit == 'directory-item')
		{
			Events.addEventHandler(element, 'click', fileManager.onDirectorySelected);
		}
	}
	
	fileManager.uploadFile = function(event)
	{
		var fileId = Data.get(event.currentTarget, 'file-id');
		
		var url = 'index.jsp?ID='+App.getSessionId();
		if (fileId)
		{
			url += '&cmd=UploadFile&item_id='+fileId;
		}
		else
		{
			url += '&cmd=UploadNewFile';
			var frm = document.forms['files'];
			var directoryId = frm.directory_id.value;
			url += '&directory_id='+directoryId;
		}
		var controller = Items.getController('FILE');
		Dialogs.openPopup(url, 'UploadFile', controller.width, controller.height);
	}
	
	fileManager.editMultipleFiles = function()
	{
		if (!Table.checkIfSelected('files', /^\d+$/))
		{
			return;
		}
		Table.submitToPopup('files', 'EditMultiple', 600, 400);
	}

	fileManager.selectDirectory = function(event)
	{
		if (!Table.checkIfSelected('files'))
		{
			return;
		}
		var url = '../directories/index.jsp?ID=' + App.getSessionId();
		url += '&mode=selectonedirectory&title=Move+to';
		url += '&callback='+event.currentTarget.id;
		Dialogs.openPopup(url, 'SelectDirectory', 500, 500);
	}
	
	fileManager.moveToDirectory = function(event)
	{
		var frm = document.forms['files'];
		Forms.addHidden(frm, 'newdirectory_id', event.detail.id);
		frm.cmd.value = 'MoveToDirectory';
		frm.submit();
	}
	
	fileManager.moveToLocation = function(event)
	{
		var moveTo = Data.get(event.currentTarget, 'location');
		var fileId = Data.get(event.currentTarget, 'file-id');
		if (fileId)
		{
			// Single file mode
			if (moveTo == 'OFFLINE')
			{
				var msg = "This action will remove the file data of the selected file from the server.\n";
				msg += "If you need the data again you have to re-upload the file.\n\n";
				msg += "Continue?";
				if (!confirm(msg)) return;
			}
			
			var url = 'index.jsp?ID='+App.getSessionId();
			url += '&cmd=MoveItem&move='+moveTo;
			url += '&item_id='+fileId;
			location.replace(url);
		}
		else
		{
			// Table mode
			if (!Table.checkIfSelected('files'))
			{
				return;
			}

			if (moveTo == 'OFFLINE')
			{
				var msg = "This action will remove the file data of the selected file(s) from the server.\n";
				msg += "If you need the data again you have to re-upload the file(s).\n\n";
				msg += "Continue?";
				if (!confirm(msg)) return;	
			}
			var frm = document.forms['files'];
			Forms.addHidden(frm, 'move', moveTo);
			frm.cmd.value = 'MoveItems';
			frm.submit();
		}
	}

	fileManager.openDirectory = function(event)
	{
		var directoryId = Data.get(event.currentTarget, 'directory-id');
		var frm = document.forms['files'];
		var currentId = frm.directory_id.value;
		parent.frames['directories'].Directories.synchronizeTo(directoryId, currentId);
	}
	
	fileManager.compressFile = function(event)
	{
		var progress = '../../common/progress_reporter.jsp?ID='+App.getSessionId();
		progress += '&progress=compress&title=Compressing file';
		Dialogs.openPopup(progress, 'CompressFile', 300, 200);
		
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=CompressItem&item_id='+Data.get(event.currentTarget, 'item-id');
		location.replace(url);
	}
	
	fileManager.decompressFile = function(event)
	{
		var progress = '../../common/progress_reporter.jsp?ID='+App.getSessionId();
		progress += '&progress=decompress&title=Decompressing file';
		Dialogs.openPopup(progress, 'DecompressFile', 300, 200);
		
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=DecompressItem&item_id='+Data.get(event.currentTarget, 'item-id');
		location.replace(url);
	}
	
	fileManager.editFileData = function()
	{
		var fileId = Data.get('page-data', 'item-id');
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=EditFileData&item_id='+fileId;
		Dialogs.openPopup(url, 'EditFileData', 800, 600);
	}
	
	// Called when radio button or checkbox for a file is clicked
	// Should update the text in the 'Selected files' field in the
	// parent form
	fileManager.onFileChecked = function(event)
	{
		var element = event.currentTarget;
		var frm = document.forms['files'];
		var mode = frm.mode ? frm.mode.value : 'default';
		if (mode == 'selectone')
		{
			window.top.SelectFile.setSelectedFile(element.value, element.title);
		}
		else if (mode == 'selectmultiple' || mode == 'selectmultiplenobuttons')
		{
			if (element.checked)
			{
				window.top.SelectFile.addSelected(element.value, element.title);
			}
			else
			{
				window.top.SelectFile.removeSelected(element.value);
			}
		}
	}
	
	// Called when name of file is clicked
	// Should select/toggle radio button or checkbox and
	// update the text in the 'Selected files' field in the
	// parent form
	fileManager.onFileSelected = function(event)
	{
		var frm = document.forms['files'];
		var mode = frm.mode ? frm.mode.value : 'default';
		var fileId = Data.get(event.currentTarget, 'item-id');
		var path = Data.get(event.currentTarget, 'path');
		
		if (mode == 'selectone')
		{
			var index = Forms.checkRadio(frm.item_id, fileId);
			window.top.SelectFile.setSelectedFile(fileId, path);
			window.top.SelectFile.returnSelected();
			App.closeWindow();
		}
		else if (mode == 'selectmultiple' || mode == 'selectmultiplenobuttons')
		{
			var checkbox = Table.toggleCheckBox('files', fileId);
			if (checkbox.checked)
			{
				window.top.SelectFile.addSelected(fileId, path);
			}
			else
			{
				window.top.SelectFile.removeSelected(fileId);
			}
		}
		else
		{
			Items.itemOnClick(event);
		}
	}
	
	// Called when name of directory is clicked
	// Should select/toggle radio button or checkbox and
	// update the text in the 'Selected files' field in the
	// parent form
	fileManager.onDirectorySelected = function(event)
	{
		var frm = document.forms['files'];
		var mode = frm.mode ? frm.mode.value : 'default';
		var directoryId = Data.get(event.currentTarget, 'item-id');
		var path = Data.get(event.currentTarget, 'path');
		if (mode == 'selectone')
		{
			window.top.SelectFile.setSelectedDirectory(directoryId, path);
		}
		else
		{
			Items.itemOnClick(event);
		}
	}
	
	fileManager.validateFile = function()
	{
		var frm = document.forms['file'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		if (frm.url && Strings.trim(frm.url.value) == '')
		{
			Forms.showNotification(frm.url, 'You must enter a URL');
			return false;
		}
		return true;
	}

	fileManager.save = function()
	{
		var frm = document.forms['file'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}
	
	fileManager.selectMimeType = function()
	{
		Dialogs.selectItem('MIMETYPE', 'selectMimeType', 0);
	}
	
	fileManager.setMimeTypeCallback = function(event)
	{
		var frm = document.forms['file'];
		frm.mime_type.value = event.detail.name;
	}

	fileManager.selectFileServer = function()
	{
		var frm = document.forms['file'];
		var url = '';
		if (frm.server_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.server_id[1].value));				
			url += '&item_id='+id;
		}
		Dialogs.selectItem('FILESERVER', 'server_id', 0, url);
	}
	
	fileManager.urlOnChange = function()
	{
		var frm = document.forms['file'];
		var url = frm.url.value;
		var lastAutoChange = Data.get(frm.url, 'last-auto-change', '');
		
		if (url && (lastAutoChange == frm.name.value))
		{
			var end = url.lastIndexOf('/');
			if (end >= 0) url = url.substring(end+1);
			frm.name.value = url;
			Data.set(frm.url, 'last-auto-change', url);
		}
	}

	return fileManager;
}();

Doc.onLoad(FileManager.initPage);
Doc.addElementInitializer(FileManager.initElements);
