<%-- $Id: list_sessions.jsp 7604 2019-02-25 12:19:50Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Session"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.core.query.Restrictions"
	import="net.sf.basedb.core.query.Expressions"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.ModeInfo"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.EmailUtil"
	import="net.sf.basedb.util.GeoLocation"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnAction"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.List"
	import="java.util.Map"
	import="java.util.Date"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.SESSION;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.LIST);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, Permission.DENIED, itemType);
final String ID = sc.getId();
final boolean createPermission = sc.hasPermission(Permission.CREATE, itemType);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);

final ModeInfo mode = ModeInfo.get(request.getParameter("mode"));
final String callback = request.getParameter("callback");
final String title = mode.generateTitle("session", "sessions");
final DbControl dc = sc.newDbControl();
ItemResultIterator<Session> sessions = null;
try
{
	final User user = User.getById(dc, sc.getLoggedInUserId());
	final boolean supportsDeviceVerification = EmailUtil.isEnabled() && 
			(user.getUseDeviceVerification() || sc.hasPermission(Permission.READ, Item.USERDEVICE));

	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);
	try
	{
		final ItemQuery<Session> query = Base.getConfiguredQuery(dc, cc, true, Session.getQuery(cc.getInclude().contains(Include.OTHERS) ? null : user), mode);
		sessions = query.iterate(dc);
	}
	catch (Throwable t)
	{
		cc.setMessage(t.getMessage());
	}
	int numListed = 0;
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, null);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	ExtensionsInvoker<ListColumnAction<Session,?>> columnsInvoker = ListColumnUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title==null ? "Sessions" : title%>" type="<%=mode.getPageType()%>" id="list-page">
	<base:head scripts="table.js,~sessions.js" styles="table.css,toolbar.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	
	<base:body>
		<h1><%=title==null ? "Sessions" : title%></h1>
		<div class="content">
		<tbl:table 
			id="sessions" 
			columns="<%=cc.getSetting("columns")%>"
			sortby="<%=cc.getSortProperty()%>" 
			direction="<%=cc.getSortDirection()%>"
			action="index.jsp"
			sc="<%=sc%>"
			item="<%=itemType%>"
			filterrows="<%=cc.getFilterRows()%>"
			subclass="fulltable"
			>
			<tbl:hidden 
				name="mode" 
				value="<%=mode.getName()%>" 
			/>
			<tbl:hidden 
				name="callback" 
				value="<%=callback%>" 
				skip="<%=callback == null%>" 
			/>
			<tbl:columndef 
				id="id"
				clazz="uniquecol"
				property="id"
				datatype="int"
				title="ID"
				sortable="true"
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="loginTime"
				property="loginTime"
				datatype="timestamp"
				title="Login time"
				sortable="true" 
				filterable="true"
				exportable="true"
				show="always" 
			/>
			<tbl:columndef 
				id="logoutTime"
				property="logoutTime"
				datatype="timestamp"
				title="Logout time"
				sortable="true" 
				filterable="true"
				exportable="true"
				formatter="<%=dateTimeFormatter%>"
			/>
			<tbl:columndef 
				id="impersonated"
				property="impersonated"
				datatype="boolean"
				title="Impersonated"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="client"
				property="client.name"
				datatype="string"
				title="Client application" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<%
			if (supportsDeviceVerification)
			{
				%>
				<tbl:columndef 
					id="device"
					property="device.name"
					datatype="string"
					title="Device" 
					sortable="true" 
					filterable="true" 
					exportable="true"
				/>
				<%
			}
			%>
			<tbl:columndef 
				id="authenticationMethod"
				property="authenticationMethod"
				datatype="string"
				title="Authentication method" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef 
				id="remoteId"
				property="remoteId"
				datatype="string"
				title="Remote ID" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef 
				id="location"
				property="location"
				datatype="string"
				title="Location" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef 
				id="comment"
				property="loginComment"
				datatype="string"
				title="Comment" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef 
				id="user"
				property="user.name"
				datatype="string"
				title="User" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef
				id="permission"
				title="Permission"
			/>
			<tbl:columndef 
				id="xt-columns" 
				extensions="<%=columnsInvoker%>" 
				jspcontext="<%=jspContext%>" 
			/>
			<div class="panelgroup bg-filled-50 bottomborder">
				<tbl:toolbar
					subclass="bottomborder"
					visible="<%=mode.hasToolbar()%>"
					>
					<tbl:button 
						id="btnColumns"
						image="columns.png" 
						title="Columns&hellip;" 
						tooltip="Show, hide and re-order columns" 
					/>
					<tbl:button 
						id="btnExport"
						data-plugin-type="EXPORT"
						image="export.png" 
						title="Export&hellip;" 
						tooltip="Export data" 
						visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
					/>
					<tbl:button 
						id="btnRunPlugin"
						data-plugin-type="OTHER"
						image="runplugin.png" 
						title="Run plugin&hellip;" 
						tooltip="Run a plugin" 
						visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
					/>
					<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
						wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
				</tbl:toolbar>
				<tbl:panel>
					<tbl:presetselector />
					<tbl:navigator
						page="<%=cc.getPage()%>" 
						rowsperpage="<%=cc.getRowsPerPage()%>" 
						totalrows="<%=sessions == null ? 0 : sessions.getTotalCount()%>" 
						visible="<%=mode.hasNavigator()%>"
					/>
				</tbl:panel>
			</div>
			<tbl:data>
				<tbl:headers>
					<tbl:headerrow>
						<tbl:header colspan="3" />
						<tbl:columnheaders />
					</tbl:headerrow>
					<%
					int numFilters = cc.getNumPropertyFilters();
					int numRows = cc.getFilterRows();
					for (int filterNo = 0; filterNo < numRows; filterNo++)
					{
						boolean lastRow = filterNo == numRows-1;
						%>
						<tbl:headerrow>
							<tbl:header subclass="index" />
							<tbl:header 
								subclass="check" 
								visible="<%=mode.hasCheck()%>"
								><base:icon 
									subclass="link table-check"
									image="check_uncheck.png" 
									tooltip="Toggle all (use CTRL, ALT or SHIFT to check/uncheck)" 
									visible="<%=lastRow%>"
								/></tbl:header>
							<tbl:header 
								subclass="check" 
								visible="<%=mode.hasRadio()%>"
								/>
							<tbl:header 
								subclass="icons" 
								visible="<%=mode.hasIcons()%>"
								>
								<base:icon
									subclass="link table-filter-row-action"
									image="add.png"
									tooltip="Add extra filter row"
									visible="<%=lastRow%>"
								/><base:icon
									subclass="link table-filter-row-action"
									image="remove.png"
									tooltip="Remove this filter row"
									visible="<%=numRows > 1 || numFilters > 0 %>"
									data-remove-row="<%=filterNo%>"
								/>
							</tbl:header>
							<tbl:propertyfilter row="<%=filterNo%>" />
						</tbl:headerrow>
						<%
					}
					%>
				</tbl:headers>
				<tbl:rows>
					<%
					if (cc.getMessage() != null)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer error"><%=cc.getMessage()%></div>
						</tbl:panel>
						<%
						cc.setMessage(null);
					}
					int index = cc.getPage()*cc.getRowsPerPage();
					int selectedItemId = cc.getId();
					if (sessions != null)
					{
						String tooltip = mode.isSelectionMode() ?
							"Select this item" : "View this item";
						while (sessions.hasNext())
						{
							Session item = sessions.next();
							int itemId = item.getId();
							String name = "TODO";
							index++;
							numListed++;
							%>
							<tbl:row>
								<tbl:header 
									clazz="index"
									><%=index%></tbl:header>
								<tbl:header 
									clazz="check" 
									visible="<%=mode.hasCheck()%>"
									><input 
										type="checkbox" 
										name="<%=itemId%>" 
										value="<%=itemId%>" 
										title="<%=name%>" 
										<%=cc.getSelected().contains(itemId) ? "checked" : ""%> 
									></tbl:header>
								<tbl:header 
									clazz="check" 
									visible="<%=mode.hasRadio()%>"
									><input 
										type="radio" 
										name="item_id" 
										value="<%=itemId%>" 
										title="<%=name%>" 
										<%=selectedItemId == itemId ? "checked" : ""%>
									></tbl:header>
								<tbl:header 
									clazz="icons" 
									visible="<%=mode.hasIcons()%>"
									>&nbsp;</tbl:header>
								<tbl:cell column="id"><%=item.getId()%></tbl:cell>
								<tbl:cell column="loginTime"><div 
									class="link table-item"
									data-item-id="<%=itemId%>"
									data-no-edit="1"
									tabindex="0"
									title="<%=tooltip%>"><%=dateTimeFormatter.format(item.getLoginTime())%></div></tbl:cell>
								<tbl:cell column="logoutTime" value="<%=item.getLogoutTime()%>" />
								<tbl:cell column="impersonated"><%=item.getImpersonated()%></tbl:cell>
								<tbl:cell column="authenticationMethod"><%=HTML.encodeTags(item.getAuthenticationMethod())%></tbl:cell>
								<tbl:cell column="remoteId"><%=HTML.encodeTags(item.getRemoteId())%></tbl:cell>
								<tbl:cell column="location"><%=HTML.encodeTags(item.getLocation())%>
									<% String mapURL = GeoLocation.getURLToMap(item.getLocationLatitude(), item.getLocationLongitude()); %>
									<base:icon href="<%=mapURL%>" image="map.png" tooltip="Show map" visible="<%=mapURL != null %>"/>								
								</tbl:cell>
								<tbl:cell column="comment"><%=HTML.encodeTags(item.getLoginComment())%></tbl:cell>
								<tbl:cell column="user"
									><base:propertyvalue 
										item="<%=item%>" 
										property="user"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="client"
									><base:propertyvalue 
										item="<%=item%>" 
										property="client"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="device"
									><base:propertyvalue 
										item="<%=item%>" 
										property="device"
										nulltext="<i>- unknown -</i>"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="permission"><%=PermissionUtil.getShortPermissions(item)%></tbl:cell>
								<tbl:xt-cells dc="<%=dc%>" item="<%=item%>">
									<tbl:cell column="xt-columns" />
								</tbl:xt-cells>
						</tbl:row>
						<%
						}
					}
					if (numListed == 0)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer note">
							<%=sessions == null || sessions.getTotalCount() == 0 ? "No sessions were found" : "No sessions on this page. Please select another page!" %>
							</div>
						</tbl:panel>
						<%
					}
					%>
				</tbl:rows>
			</tbl:data>
		</tbl:table>
		</div>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnOk" title="Ok" visible="<%=mode.hasOkButton()%>" />
			<base:button id="close" title="Cancel" visible="<%=mode.hasCancelButton()%>" />
			<base:button id="close" title="Close" visible="<%=mode.hasCloseButton()%>" />
		</base:buttongroup>
		
	</base:body>
	</base:page>
	<%
}
finally
{
	if (sessions != null) sessions.close();
	if (dc != null) dc.close();
}
%>
